# jasyllablesep
Japanese text parser to separate Katakana string into syllables.

# Usage

## Install
```
pip install jasyllablesep
```

## Code example

```Python
import jasyllablesep
print(jasyllablesep.parse("シンシュンシャンソンショー"))
```

```
['シン', 'シュン', 'シャン', 'ソン', 'ショー']
```


